@@ -64,12 +64,12 @@ get '/ajax/content/report/nodesdiscovered' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json( \@results );
-        template 'ajax/report/nodesdiscovered.tt', { results => $json };
+        template 'ajax/report/nodesdiscovered.tt', { results => $json }, { layout => undef };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
         template 'ajax/report/nodesdiscovered_csv.tt',
-            { results => \@results };
+            { results => \@results }, { layout => undef };
     }
 };
 
