@@ -37,11 +37,11 @@ get '/ajax/content/report/portutilization' => require_login sub {
 
     if (request->is_ajax) {
         my $json = to_json (\@results);
-        template 'ajax/report/portutilization.tt', { results => $json };
+        template 'ajax/report/portutilization.tt', { results => $json }, { layout => undef };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
-        template 'ajax/report/portutilization_csv.tt', { results => \@results, };
+        template 'ajax/report/portutilization_csv.tt', { results => \@results, }, { layout => undef };
     }
 };
 
